==> openGion_core_5.4.4.0.zip: ge/db/hsql/sql/01_TABLE/GE80S.sql <==
/**************************************************************************/
/* GE80 ( FAQテーブル )                                                   */
/*                                                                        */
/* Created : 2012/02/01 17:06:09                                          */
/**************************************************************************/
CREATE TABLE GE80 (
   UNIQ      IDENTITY                                   /* 10  ユニークキー   */
 , SYSTEM_ID VARCHAR(10)                  NOT NULL      /* 20  システムID     */
 , SYSCODE   VARCHAR(20)      DEFAULT '*' NOT NULL      /* 30  システムコード */
 , KBFAQ     VARCHAR(1)       DEFAULT '0' NOT NULL      /* 40  FAQ区分        */
 , QANO      VARCHAR(20)                  NOT NULL      /* 50  質問番号       */
 , CDBNRI    VARCHAR(3)                                 /* 60  分類コード     */
 , KNRNGUI   VARCHAR(200)                               /* 70  関連画面ID     */
 , TITLE     VARCHAR(300)                               /* 80  タイトル       */
 , NAIYO     VARCHAR(4000)                              /* 90  内容           */
 , SEQNO     INTEGER          DEFAULT 0   NOT NULL      /* 100 表示順         */
 , TAG       VARCHAR(200)                               /* 110 タグキーワード */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL      /* 120 状態フラグ     */
 , DYSET     VARCHAR(14)                                /* 130 登録日時       */
 , PGSET     VARCHAR(10)                                /* 140 作成PG         */
 , PGPSET    VARCHAR(10)                                /* 150 作成親PG       */
 , USRSET    VARCHAR(10)                                /* 160 作成社員       */
 , DYUPD     VARCHAR(14)                                /* 170 更新日時       */
 , PGUPD     VARCHAR(10)                                /* 180 更新PG         */
 , PGPUPD    VARCHAR(10)                                /* 190 更新親PG       */
 , USRUPD    VARCHAR(10)                                /* 200 更新者         */
);

==> openGion_core_5.5.0.0.zip: ge/db/hsql/sql/01_TABLE/GE80S.sql <==
/**************************************************************************/
/* GE80 ( FAQテーブル )                                                   */
/*                                                                        */
/* Created : 2012/03/02 18:46:37                                          */
/**************************************************************************/
CREATE TABLE GE80 (
   UNIQ      IDENTITY                                   /* 10  ユニークキー   */
 , SYSTEM_ID VARCHAR(10)                  NOT NULL      /* 20  システムID     */
 , SYSCODE   VARCHAR(20)      DEFAULT '*' NOT NULL      /* 30  システムコード */
 , KBFAQ     VARCHAR(1)       DEFAULT '0' NOT NULL      /* 40  FAQ区分        */
 , QANO      VARCHAR(20)                  NOT NULL      /* 50  質問番号       */
 , CDBNRUI   VARCHAR(3)                                 /* 60  分類コード     */
 , KNRNGUI   VARCHAR(200)                               /* 70  関連画面ID     */
 , TITLE     VARCHAR(300)                               /* 80  タイトル       */
 , NAIYO     VARCHAR(4000)                              /* 90  内容           */
 , SEQNO     INTEGER          DEFAULT 0   NOT NULL      /* 100 表示順         */
 , TAG       VARCHAR(200)                               /* 110 タグキーワード */
 , FGJ       VARCHAR(1)       DEFAULT '1' NOT NULL      /* 120 状態フラグ     */
 , DYSET     VARCHAR(14)                                /* 130 登録日時       */
 , PGSET     VARCHAR(10)                                /* 140 作成PG         */
 , PGPSET    VARCHAR(10)                                /* 150 作成親PG       */
 , USRSET    VARCHAR(10)                                /* 160 作成社員       */
 , DYUPD     VARCHAR(14)                                /* 170 更新日時       */
 , PGUPD     VARCHAR(10)                                /* 180 更新PG         */
 , PGPUPD    VARCHAR(10)                                /* 190 更新親PG       */
 , USRUPD    VARCHAR(10)                                /* 200 更新者         */
);
